'    ***  Spallation-Model Code SPACS  ***

'    Copyright 2016:
'       Dr. Christelle Schmitt,
'         GANIL, Boulevard Henri Becquerel, B.P. 5027
'         14076 CAEN Cedex 5, France,
'       Dr. Karl-Heinz Schmidt, 
'         Rheinstrasse 4, 64390 Erzhausen, Germany
'         and 
'       Dr. Aleksandra Kelic-Heil,
'         GSI, Planckstrasse 1, 64291 Darmstadt, Germany
'
'    This program is free software: you can redistribute it and/or modify
'    it under the terms of the GNU General Public License as published by
'    the Free Software Foundation, either version 3 of the License, or
'    (at your option) any later version.
'
'    This program is distributed in the hope that it will be useful,
'    but WITHOUT ANY WARRANTY; without even the implied warranty of
'    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
'    GNU General Public License for more details.
'
'    You should have received a copy of the GNU General Public License
'    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Print "  **********************************************************************"
    Print "  * SPACS - Calculates cross sections of projectile fragments in       *"
    Print "  * proton-induced                                                     *"
    Print "  * spallation reactions (C. Schmitt, K.-H. Schmidt, A. Kelic-Heil,    *"
    Print "  * Phys. Rev. C 90 (2014) 064605)                                     *"
    Print "  * Using EPAX Version 3.1 (K. Suemmerer, PRC86 (2012) 014601)         *"
    Print "  * formulas as basis for calculating width and most probable charge.  *"
    Print "  * Total reaction cross sections calculated according to              *"
    Print "  * R.K. Tripathi et al., NIMB 117 (1996) 347 for proton  and          *"
    Print "  * R.K. Tripathi et al., NIMB 129 (1997) 11 for neutron.              *"
    Print "  **********************************************************************"

  /' Internal variables '/
    Dim As Single _
             Z,A,Fcorr,j,Fjprf,FGAMMA,fcorrmem, _     
             DU,SN,T,SP,BP,GAMMAN,GAMMAG,GAMMAP, _
             r,zprob,cpscale,Amax,SA,BA,GAMMAA,cascale, _
             norm, R_XS_SUM,sigtot,fcut,fperi,fbu,A_cut,A_length, _
             R_XS, _
             Rhelp 
             
    Dim As Integer _         
             IRC15,irfluct_switch,IRC,II,JJ
             
    Dim As String Ctarget         
             
    Redim As Single R_XSS(0 To 200, 0 To 100)
    Redim As Single sigma(0 To 300)
    Redim As Single zmean(0 To 300)         

    #Include "Utilities.bas"
    #Include "sigtot.bas"
    #Include "SPACS_SP.bas"
    #Include "Isostabil.bas"
    #Include "Read_Data.bas"
    

  /' Input parameters: '/
    Dim Shared As Single ZP = 82           /'Nuclear charge of projectile '/
    Dim Shared As Single AP = 200          /' Mass of projectile '/
    Dim Shared As Single ZT = 0            /' Nuclear charge of target '/
    Dim Shared As Single At = 0            /' Mass of target '/
    Dim Shared As Single EP = 1000         /' E/A (in MeV) of projectile '/
    Dim Shared As Single IFJPRF = 1       /' =1 for Fjprf on '/
    Dim Shared As Single IFcorr = 1        /' =1 for Fcorr on '/     
    Dim Shared As Single IFgamma = 1       /' =1 for Fgamma on '/
    Dim Shared As Single JCR = 5           /' Critical angular momentum '/
    Dim Shared As Single D = 1.            /' Width parameter of angular momentum '/
    Dim Shared As Single Cnscale = 5.5e-3  /' Neutron-width strenght '/
    Dim Shared As Single rfluct = 0.28     /' Statistical fluctuation contr. to width '/
                      
 Print
 Input "Enter Z and A of heavy nucleus: ",ZP,AP
 Input "Spallation by protons (p) or neutrons (n): ",Ctarget
 Input "Enter bombarding energy in A MeV: ",EP
 Print
 
 If Ctarget = "p" Then
   Zt = 1
   At = 1
 End If  
 If Ctarget = "n" Then
   Zt = 0
   At = 1
 End If   

 If ((Zp <= 0) Or (Ap <= 0) Or (Zt < 0) Or (At <= 0)) Then 
   Print '<E>: Input parameters incorrect!'
   End
 End If


 R_XS_SUM = 0.E0   /' Sum of all cross sections, for normalization after Fcorr '/

 For Z = 1 To Zp+2 Step 1
   For A = MAX(Z,Int(Z * 2.2E0 - 30)) To Min(Ap-Zp+Z+2,Z*3 + 20) Step 1
     R_XSS(A-Z,Z) = 0.E0
   Next A
 Next Z

 sigtot = U_sigtot(Ap,Zp,Ep,At,Zt)    
 Print "sigtot =";sigtot;" mb"
   
 For Z = 1 To Zp+2 Step 1
   For A = MAX(Z,Int(Z * 2.2E0 - 30)) To Min(Ap-Zp+Z+2,Z*3 + 20) Step 1

     fcorr = Fcorrtab(A-Z,Z)      /' Factor for even-odd effect '/
     fcorrmem = fcorr

     JJ = Int(A-Z)
     II = Int(Z)
     ISOSTABIL(JJ,II,IRC)  /' IRC=0 bound nuclei '/
     If (IRC < 0) Then 
       R_XS = 0.E0
       GOTO L100
     End If

     If (Z > Zp+2) Then 
       R_XS = 0.E0
       GOTO L100
     End If

     If (A = Ap And Z = Zp) Then 
       R_XS = 0.E0
       GOTO L100
     End If

     If (A > Ap) Then
       R_XS = 0.E0
       GOTO L100
     End If

     SPACS_SP(Zp,Ap,Ep,Zt,At,Z,A,sigtot,rfluct,R_XS,r,zprob)

     sigma(A) = 1.e0/r
     zmean(A) = zprob
'Print Z,A,sigma(A),zmean(A)        

     /' Start of even-odd: '/
     If (ifcorr = 1) Then 
       /' Influence of gamma emission on even-odd effect: '/
       If (ifgamma = 1) Then 
         /' Nuclear temperature of the mother nucleus: '/
         DU = ShellMOtab(A-Z,Z)  /' Shell effects '/
         T = 1.e0 / ( (0.0570e0 + 0.00193e0*DU) * A^0.6666667e0) /' from  PRC 80 (2009) 054310 '/
         /' Gamma-emission width Gammag from: '/
         /' Systematics of Low-Lying Level Densities and Radiative Widths 
            A. V. Ignatyuk
            Hadrons Nuclei Appl. 3 (2001) 287-292 /
            Structure of the nucleus at the dawn of the century,
            Proc. Conf. Bologna 2000, Word Scientific ISBN 9789812810922 '/
         Gammag = 0.624e0 * A^1.6e0 * ( T^5 )  /' in meV '/
         Gammag = Gammag * 1.E-9       /' in MeV '/


         /' Neutron emission into one level (e.g. the ground state of even-even daugthers) '/
         /' calculated as geometrical cross section *temperature / mother level density * adjustable factor'/
         Sn = SNtab(A-Z,Z) /' Neutron separation energy '/
         Gamman = 0.e0
         If (T > 0.e0 And Sn < 50.e0 And A > 1.E0) Then Gamman = (A-1.e0)^0.6666667e0 * T  / (1.e0/T * _
                                    exp(Sn/T)) * Cnscale
   
         /' Proton emission '/
         Sp = SPtab(A-Z,Z) /' Proton separation energy '/
         Bp = BPtab(A-Z,Z) /' Coulomb barrier for proton emission '/
         Gammap = 0.e0
         Cpscale = Cnscale * 938.3e0/939.6e0
         If (T > 0.e0 And Sp < 50.e0 And A > 1.E0) Then _ 
           Gammap = (A-1.e0)^0.6666667e0 * (2*T^2/(2*T+Bp)) / _
                                          (1/T*exp((SP+Bp)/T))*Cpscale

         /' Alpha emisison '/
         Ba = 1.44E0*(Z-2.E0)*2.E0/(1.87E0*((A-4.E0)^0.33333E0 + 4.E0^0.33333E0))
         Sa = SAtab(A-Z,Z)
         Gammaa = 0.e0
         Cascale = Cnscale * 3727.4e0/939.6e0
         If (T > 0.e0 And Sa < 50.e0 And A > 4.E0) Then _ 
           Gammaa = (A-4.e0)^0.6666667e0 * (2*T^2/(2*T+Ba)) / _
                                          (1/T*exp((Sa+Ba)/T))*Cascale

         /' Relative weight of gamma emission
            (is a measure for the attenuation of fine structure in the yields) '/
         fgamma = Gammag / (Gamman + Gammag + Gammap + Gammaa)

         If (fcorr > 0.e0) Then Fcorr = exp( log(Fcorr) * (1 - fgamma) )  /' attenuation of even-odd staggering '/
                                                                                     /' due to gamma emission '/
       End If

       /' attenuation of even-odd staggering due to angular momentum: '/
       If (ifjprf = 1) Then 
         /' de Jong et al, for fragmentation '/
         j = sqr(0.16e0*Ap^0.666667*(Ap-A)*(2.e0*Ap+A)/9.e0/(Ap-1.e0))-0.5e0
         /' in spallation jprf is larger '/
         /'   j = j * 2.e0; '/
         fjprf = 1./(1.+exp((J-JCR)/D))

         If(fcorr > 0.e0) Then fcorr = exp( log(Fcorr) * fjprf ) 
       End If
     End If
'Print Z,A, R_XS,Fcorr
     If(ifcorr = 1) Then R_XS = R_XS * Fcorr

     R_XS_SUM = R_XS_SUM + R_XS

     L100: R_XSS(A-Z,Z) = R_XS

   Next A
 Next Z

 NORM = Sigtot / R_XS_SUM  /' Factor to normalize to sigtot after all corrections '/
 Print "Norm = ";NORM

 For Z = 1 To Zp+2
   For A = MAX(Z,Int(Z * 2.2E0 - 30)) To Min(Ap-Zp+Z+2,Z*3 + 20)
     R_XSS(A-Z,Z) = R_XSS(A-Z,Z) * NORM
   Next A
 Next Z  
 
 #Include "OutDMP.bas"
 
 Print 
 Print "  *********************************************************************"
 Print "  * Note that SPACS does not consider fission and multifragmentation! *"
 Print "  * Therefore, cross sections for fissile systems                     *"
 Print "  * and the cross sections of lighter products for center-of-mass     *" 
 Print "  * energies > a few GeV must be considered with caution.             *"
 Print "  * Light charged particles from evaporation are also not included.   *" 
 Print "  *********************************************************************"

 #Include "Plotting.bas"
 sleep

 L300:  
End

