 Declare Sub SPACS_SP(Zp As Single, Ap As Single, Ep As Single, _
                      Zt As Single, At As Single, Z As Single, A As Single, _
                      sigtot As Single, rfluct As Single, Byref spacsv1 As Single, _
                      Byref r As Single, Byref zprob As Single) 


 Sub SPACS_SP(Zp As Single, Ap As Single, Ep As Single, _
              Zt As Single, At As Single, Z As Single, A As Single, _
              sigtot As Single, rfluct As Single, Byref spacsv1 As Single, _ 
              Byref r As Single, Byref zprob As Single) 

            /'*****************************************'/
            /'*                                       *'/
            /'*                 SPACS                 *'/
            /'*                                       *'/
            /'*     An Empirical  Parametrization     *'/
            /'*      of Projectile-Spallation         *'/
            /'*            Cross Sections             *'/
            /'*                                       *'/
            /'*****************************************'/


 /'*********************************************************************'/
 /'* Returns cross section (in barn) for fragment (A,Z) in projectile  *'/
 /'* spallation of projectile (Ap,Zp) on target (At,Zt) at projectile  *'/
 /'* energy per nucleon EP (MeV/per nucleon)                           *'/
 /'*********************************************************************'/


   Dim As Single fract_corr
   Dim As Integer irfluct_switch,IRC,I,J
   Dim As Single epaxv2             ' output 
   Dim As Single Ap13,At13,sigma
   Dim As Single S
   Dim As Single p
   Dim As Single f_mod_y
   Dim As Single f_mod
   Dim As Single zbeta
   Dim As Single delta
   Dim As Single dq
   Dim As Single u_n
   Dim As Single u_p
   Dim As Single expo
   Dim As Single fract
   Dim As Single z_exp
   Dim As Single dfdz
   Dim As Single yield_a
   Dim As Single zbeta_p

   /'************ Constants *******************************'/
   /' centroid rel. to beta-stability '/
   Static As Single p_delta(1 To 6) => { _
                    -1.3327E+00, _    
                    +5.358E-02, _ 
                    -2.058E-4, _ 
                    4.9639E-7, _
                    +1.9E-04, _
                    +131.E0} 

    /' slope of mass yield curve '/
    Static As Single p_P(1 To 2) => { _ 
                -1.731E0 _
                -0.01399}

    /' scale factor for xsect in barn '/
    Static As Single p_S(1 To 2) => { _
                0.27, _            
                1.80}

    Static As Single p_R(1 To 4) => { _
                +3.65E0, _   /'  width parameter R '/
                -0.0157, _   /' param p_R(1) '/
                 3.2e-5, _   /' p_R(2,3) are dependent now on abs(Zp-Zp_beta), see below '/
                 98.0}    

    Static As Single p_Un(1 To 2) => { _
                 0.934, _
                 0.9984}     /' slope par. n-rich side of Z distr.  '/

    /' Slope par. p-rich side of Z distr '/
    Static As Single p_Up(1 To 2) => { _ 
                 2.1, _
                 0.0013}     

    Static As Single p_mn(1 To 2) => { _
                1.20, _            
                0.40}

    Static As Single p_mp(1 To 3) => { _
                 -11.25, _            /' memory effect p-rich projectiles '/
                 +11.00, _           
                  -0.75}   

    Static As Single corr_d(1 To 4) => { _
                    -25.0, _        /' correction close to proj.: centroid dzp '/
                     0.80, _
                     0.90, _
                   -95.E0}          /' d(3,4) added for spallation '/

    Static As Single corr_r(1 To 2) => { _
                  +2800.0, _         /' correction close to proj.: width R '/ 
                   0.86}    

    Static As Single corr_y(1 To 2) => { _
                   0.75, _            /' correction close to proj.: Yield_a '/
                   0.50}  

    Static As Single par_b(1 To 2) => { _
                   2.3e-3, _          /' correction for very neutron-rich fragments '/
                   2.4}  


 spacsv1=-999.0

 Ap13 = Ap^0.33333E0
 At13 = At^0.33333E0

 /'******************************************************************************'/

  /'* Treatment for spallation reactions (proton-induced reactions) *'/

    Dim As Single Acent,Acent_fluct,Ycent,Yperi,Adiff_eff,Alength,eps,Ysum
    Dim As Single pa,Eexcit,Temp,fbu,Aprefr,ur_corr,argum,Afluct,Aperiph,Adiff
    /' Parameters: '/
    Dim As Single   alpha_cent = 1.39  
    Dim As Single   eps_cent = 0.75
    Dim As Single   p_Afluct(1 To 2) => {7.876,-0.0066}   
    Dim As Single   alpha_length  = 0.7
    Dim As Single   eps_fluct = 0.5 
    Dim As Single   delta_fluct = 0.0
    Dim As Single   Bperiph
    Dim As Single   p_Adiff(1 To 2) => {1.572,-0.00132}  
    Dim As Single   p_Aperiph(1 To 2) => {0.905,-9.868e-4}  
    Dim As Single   beta_cent = 1560
    Dim As Single   Gperiph = 0.9  
    Dim As Single   eps_periph = -0.05
    Dim As Single   delta_periph = 0.065

    /' Acent: mean mass loss for central collisions '/
    /' Saturation of mass loss at high energies: Acut<Ap included '/
        Acent = Ap*(1.E0-exp(-log(alpha_cent/exp(Ap/beta_cent))*(Ep/1.E+3)^eps_cent))  /''/

    /' Acent_fluct: Fluctuations of maximum mass loss '/

        Afluct = p_Afluct(1)+p_Afluct(2)*Ap   

        Acent_fluct = afluct* Acent^delta_fluct * (Ep/1.E3)^eps_fluct /''/

    /' Alength: norm. length of tunnel drawn by the projectile into the target nucleus '/
        If A <= (Ap + alpha_length * Acent_fluct  - Acent) Then     
         Alength = 1.E0                                        
        Else                                                    

         Alength = sqr( (Acent + alpha_length * Acent_fluct)^2 - _
                    (Ap + alpha_length * Acent_fluct - Acent - A)^2 ) / _
            (Acent + alpha_length * Acent_fluct)

        End If

    /' Ycent: exponential decrease towards lower masses due to fluctuations '/
         argum =  ( (Ap - Acent)-A )/Acent_fluct
    /' Limit to avoid overflow problems in Ycent; if argum>19 then Ycent=0 '/
         if(argum > 19.E0) then argum = 19.E0
         Ycent =  Alength / (1.E0 + exp(argum))

    /' Yperi: enhancement of cross section for peripheral collisions: '/
         Adiff = p_Adiff(1)+p_Adiff(2)*Ap        
         eps = (A - (Ap - Adiff)) / Adiff 
        If (eps < -50.E0) Then eps = -50.E0  /' To avoid underflow '/
    /' Ultrarelativistic correction in Bperiph: '/
        Bperiph = Gperiph /(1.E0+exp(-((log(1.E+3)/log(Ep))^6+eps_periph) /delta_periph)) 
        Aperiph = p_Aperiph(1)+p_Aperiph(2)*Ap     
        Yperi = Aperiph * EXP(eps)*  (Ep/1.E3)^Bperiph /''/

        yield_a = Ycent + Yperi

    /' Approximate integral of mass yields: '/
      Ysum = Acent

 /'**************************************************'/

    /' Normalize to total x-section '/
       yield_a = yield_a * Sigtot / Acent

    /' Calculate maximum of charge dispersion zprob '/
        zbeta = A/(1.98E0+0.0155E0*A^(2.E0/3.E0))
        zbeta_p = Ap/(1.98E0+0.0155E0*Ap^(2.E0/3.E0))


        If(A >= p_delta(6)) Then 
         delta = p_delta(1) + p_delta(2)*A + p_delta(3)*A^2 + p_delta(4)*A^3 
        Else
         delta = p_delta(5)*A*A
        End If

         f_mod=1.0E0

         If (A/Ap > corr_d(2)) Then  
          F_Mod = corr_d(1)*(A/Ap-corr_d(2))^2 + 1.E0
           If(A/Ap > corr_d(3)) Then        /' additional term for spallation '/
            F_Mod = F_Mod + corr_d(4)*(A/Ap-corr_d(3))^3 
           End If
         End If

         Delta = Delta*F_Mod

         zprob = zbeta + delta 

    /' Correction for proton- and neutron-rich projectiles '/
        If ((Zp-zbeta_p) > 0) Then  /'------------- p-rich '/
          dq = exp(p_mp(1) + A/Ap*p_mp(2))     /' memory effect close to Ap '/
          If(A/Ap<0.5e0) Then dq = dq + p_mp(3)*((Ap-A)/Ap)^2.E0  /' memory effect for light residues '/

          If(A >= p_delta(6)) Then 
           dq = dq + exp(-(corr_d(3)-A/Ap)^2/5.e-3)
          End If

        Else                       /'------------- n-rich '/
          dq = p_mn(1)*(A/Ap)^6.0E0 + _  /' memory effect close to Ap '/
                 p_mn(2)*((Ap-A)/Ap)^2.0E0   /' mem. eff. for small A '/
        End If

         zprob = zprob + dq*(Zp-zbeta_p)

    /' Small corr. since Xe-129 and Pb-208 are not on Z_beta line '/
         zprob = zprob + 0.0020E0*A

   /' ***   calculate width parameter R '/   
  If (A < p_r(4)) Then      /' Width should go to zero when A -> 0 '/
    r = -1.E0 * log(p_r(1) * A / 112.E0)
  Else
   r = (-0.07932E0*abs(Zp-zbeta_p)+0.01638E0)*A + _
       (3.4181E-4*abs(Zp-zbeta_p)-1.0624E-4)*A*A - _
       (-4.4807E0*abs(Zp-zbeta_p)+1.8122E0) 

  End If

    r = exp(r)

/' additional width due to fluctuations '/
/' close to projectile it is needed only if Gamman and Gammap are '/
/' comparable '/
 If (A < p_r(4) And A/Ap < corr_r(2)) Then
 /' sigma^2 = 1/(2*R) '/
    sigma = sqr(1.e0/(2.E0*r) + rfluct^2)
    r = 1.e0/(2.E0*sigma^2)
 End If

 /' **   change width according to dev. from beta-stability '/
 /'  correction for proton- and neutron-rich projectiles '/
       If((Zp-zbeta_p) > 0 ) Then /'------------- p-rich '/
         r = r * 2.78E0*exp(0.178E0*(Zp-zbeta_p))     
       Else                      /'------------- n-rich '/
         r = r * 2.78E0*exp(0.0212E0*(Zp-zbeta_p)) 
       End If
 
 /' **   modification close to projectile '/
        f_mod=1.0E0
 If (A/Ap > corr_r(2)  ) Then
   f_mod = exp(corr_r(1)*sqr(Ap)*(A/Ap-corr_r(2))^5.E0)  
   If (f_mod < 1.E0) Then f_mod = 1.E0
 End If
      r = r*f_mod

 /' ***   calculate slope parameters u_n, u_p '/
          U_n = p_un(1) + p_un(2)*A/Ap
          U_p = p_up(1) + p_up(2)*Ap  

 /' ***   calculate charge dispersion '/
 If ((zprob-Z) > 0) Then  /''/
 /' **     neutron-rich '/
          expo = -r*(abs(zprob-Z))^u_n
          fract   =  exp(expo)*sqr(r/3.14159E0)
 /' corection for very neutron-rich fragments '/
         If ((zbeta-Z) > (Zp-zbeta_p+par_b(2))) Then 
          fract = fract * 10^(-par_b(1)*abs(Zp-zbeta_p)*(zbeta-Z+Zp-Zbeta_p+par_b(2))^3)
         End If

        Else 
 /' **     proton-rich '/
          expo = -r*(abs(zprob-Z))^u_p
          If (expo < -70.E0) Then expo = -70.E0 /' To avoid underflow '/

          fract   =  exp(expo)*sqr(r/3.14159E0)
 /' *     go to exponential slope '/

          dfdz = 1.2E0 + 0.647E0*(A/2.E0)^0.3E0
          z_exp = zprob + dfdz * log(10.E0) / (2.E0*r)
          If ( Z > z_exp ) Then 
          expo = -r*(abs(zprob-z_exp))^u_p
          If (expo < -70.E0) Then expo = -70.E0 /' To avoid underflow '/

            fract   =  exp(expo)*sqr(r/3.14159E0) _
                       / (10.E0^(dfdz))^(Z-z_exp)
          End If

/' Correction for Ch.Exch. channels '/
       fract_corr = 1.E0
/' EP dependence, extracted from Fig. 8 PRC 70 (2004) 064608 '/
      If (Z > Zp And Ep < 1000.E0) Then 
       fract_corr = fract_corr * (0.34508E0 + 4.27305E0*exp(-(Ep/1000.E0)/0.53384E0))
       fract = fract * fract_corr
      End If

        End If

        spacsv1=fract*yield_a

      End Sub
